pub struct ExclusionDiff<T> {
pub before_cell_exclusion: Vec<T>,
pub after_cell_exclusion: Vec<T>,
}Fields
before_cell_exclusion: Vec<T>the results of the shortest-path calculation before the cells have been excluded from the graph.
after_cell_exclusion: Vec<T>the results of the shortest-path calculation after the cells have been excluded from the graph.