Enum h3ron_graph::algorithm::path::DirectedEdgePath
source · [−]pub enum DirectedEdgePath {
OriginIsDestination(H3Cell),
DirectedEdgeSequence(Vec<H3DirectedEdge>),
}Expand description
DirectedEdgePath describes a path between a cell and another.
Variants
OriginIsDestination(H3Cell)
path is empty as origin and destination are the same.
DirectedEdgeSequence(Vec<H3DirectedEdge>)
a sequence of edges describing the path.
The edges in the vec are expected to be consecutive.
The cost is the total cost summed for all of the edges.
Implementations
sourceimpl DirectedEdgePath
impl DirectedEdgePath
pub fn is_empty(&self) -> bool
pub fn origin_cell(&self) -> Result<H3Cell, Error>
pub fn destination_cell(&self) -> Result<H3Cell, Error>
pub fn to_linestring(&self) -> Result<LineString<f64>, Error>
pub fn edges(&self) -> &[H3DirectedEdge]