Enum h3ron_graph::algorithm::path::Path [−][src]
Path describes a path between a cell and another.
Variants
OriginIsDestination(H3Cell, W)path is empty as origin and destination are the same.
Tuple Fields of OriginIsDestination
0: H3Cell1: Wa sequence of edges describing the path.
The edges in the vec are expected to be consecutive.
The cost is the total cost summed for all of the edges.
Implementations