pub trait ShortestPathOptions {
// Provided methods
fn max_distance_to_graph(&self) -> u32 { ... }
fn num_destinations_to_reach(&self) -> Option<usize> { ... }
}Expand description
Generic type parameters:
W: The weight used in the graph.
Provided Methods
Sourcefn max_distance_to_graph(&self) -> u32
fn max_distance_to_graph(&self) -> u32
Number of cells to be allowed to be missing between a cell and the graph while the cell is still counted as being connected to the graph.
Implemented using see NearestGraphNodes.
Sourcefn num_destinations_to_reach(&self) -> Option<usize>
fn num_destinations_to_reach(&self) -> Option<usize>
number of destinations to reach. Routing for the origin cell will stop when this number of destinations are reached. When not set, routing will continue until all destinations are reached
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".