pub trait WithinWeightThreshold<W> {
    fn cells_within_weight_threshold(
        &self,
        origin_cell: H3Cell,
        weight_threshold: W
    ) -> H3CellMap<W>; }
Find all cells connected to the graph around a origin cell within a given threshold

Required methods

Find all cells connected to the graph within a given weight_threshold around the given origin_cell

Implementors