pub struct H3EdgeGraph<W> {
    pub edges: H3EdgeMap<W>,
    pub h3_resolution: u8,
}

Fields

edges: H3EdgeMap<W>h3_resolution: u8

Implementations

This has to generate the node list first, so its rather expensive to call.

get all edges in the graph leading from this edge to neighbors

get all edges in the graph leading to this cell from its neighbors

cells which are valid targets to route to

This is a rather expensive operation as nodes are not stored anywhere and need to be extracted from the edges.