pub struct LongEdge {
    pub in_edge: H3DirectedEdge,
    pub out_edge: H3DirectedEdge,
    /* private fields */
}
A LongEdge is an artificial construct to combine a continuous path of H3DirectedEdge values into a single edge.

This intended to be used to compress longer paths into a single edge to reduce the number of nodes to visit during routing.

Fields

in_edge: H3DirectedEdgeout_edge: H3DirectedEdge

Implementations

length of self as the number of contained h3edges

the path of the longedge described by multiple, successive H3DirectedEdge values