pub enum GapBridgedCellNode {
    DirectConnection(H3Cell),
    WithGap(H3CellH3Cell),
    NoConnection(H3Cell),
}
the type of membershipt a cell has within a graph

Variants

DirectConnection(H3Cell)

the cell is connected to the graph

WithGap(H3CellH3Cell)

cell self.0 is not connected to the graph, but the next best neighbor self.1 is

NoConnection(H3Cell)

cell is outside of the graph

Implementations