pub struct PreparedH3EdgeGraph<W> { /* private fields */ }
A prepared graph which can be used with a few algorithms.

Consequent H3DirectedEdges without forks get extended by a LongEdge to allow skipping the individual H3DirectedEdge values for a more efficient graph traversal.

%3 c1 c1 c2 c2 c1->c2 c5 c5 c1->c5 c3 c3 c2->c3 c4 c4 c3->c4 c4->c5 c6 c6 c5->c6 c10 c10 c5->c10 c11 c11 c5->c11 c14 c14 c5->c14 c7 c7 c6->c7 c8 c8 c7->c8 c9 c9 c8->c9 c9->c10 c12 c12 c11->c12 c13 c13 c12->c13 c13->c14

%3 h3cell H3 cell uint64 h3edge Outgoing H3 edge direction n [..] uint64 uint64 h3cell:p->h3edge attributes_n Attributes implementation specific h3edge:p_n->attributes_n:p longedge_n In H3 Edge uint64 Out H3 Edge uint64 Contained Edges Compressed bitmap Contained Edge Sequence Compressed uint64 vector Aggregated attributes implementation specific h3edge:p_n->longedge_n:p

Implementations

count the number of edges in the graph

The returned tuple is (num_edges, num_long_edges)

iterate over all edges of the graph

iterate over all edges of the graph, while skipping simple H3DirectedEdge which are already covered in other LongEdge instances of the graph.

This function iterates the graph twice - the first time to collect all edges which are part of long-edges.