Trait h3ron_graph::algorithm::shortest_path::ShortestPathOptions [−][src]
pub trait ShortestPathOptions {
fn num_gap_cells_to_graph(&self) -> u32 { ... }
fn num_destinations_to_reach(&self) -> Option<usize> { ... }
}Expand description
Generic type parameters:
W: The weight used in the graph.
Provided methods
fn num_gap_cells_to_graph(&self) -> u32
fn num_gap_cells_to_graph(&self) -> u32
Number of cells to be allowed to be missing between a cell and the graph while the cell is still counted as being connected to the graph
fn num_destinations_to_reach(&self) -> Option<usize>
fn num_destinations_to_reach(&self) -> Option<usize>
number of destinations to reach. Routing for the origin cell will stop when this number of destinations are reached. When not set, routing will continue until all destinations are reached