Struct h3ron_graph::graph::h3edge::H3EdgeGraph
source · [−]Fields
edges: H3EdgeMap<W>h3_resolution: u8Implementations
sourceimpl<W> H3EdgeGraph<W>where
W: PartialOrd + PartialEq + Add + Copy,
impl<W> H3EdgeGraph<W>where
W: PartialOrd + PartialEq + Add + Copy,
pub fn new(h3_resolution: u8) -> Self
sourcepub fn num_nodes(&self) -> Result<usize, Error>
pub fn num_nodes(&self) -> Result<usize, Error>
This has to generate the node list first, so its rather expensive to call.
pub fn num_edges(&self) -> usize
pub fn edge_weight(&self, edge: &H3DirectedEdge) -> Option<&W>
sourcepub fn edges_from_cell(
&self,
cell: &H3Cell
) -> Result<Vec<(&H3DirectedEdge, &W)>, Error>
pub fn edges_from_cell(
&self,
cell: &H3Cell
) -> Result<Vec<(&H3DirectedEdge, &W)>, Error>
get all edges in the graph leading from this edge to neighbors
sourcepub fn edges_to_cell(
&self,
cell: &H3Cell
) -> Result<Vec<(&H3DirectedEdge, &W)>, Error>
pub fn edges_to_cell(
&self,
cell: &H3Cell
) -> Result<Vec<(&H3DirectedEdge, &W)>, Error>
get all edges in the graph leading to this cell from its neighbors
pub fn add_edge_using_cells(
&mut self,
cell_from: H3Cell,
cell_to: H3Cell,
weight: W
) -> Result<(), Error>
pub fn add_edge_using_cells_bidirectional(
&mut self,
cell_from: H3Cell,
cell_to: H3Cell,
weight: W
) -> Result<(), Error>
pub fn add_edge(&mut self, edge: H3DirectedEdge, weight: W) -> Result<(), Error>
pub fn try_add(&mut self, other: Self) -> Result<(), Error>
sourcepub fn nodes(&self) -> Result<H3CellMap<NodeType>, Error>
pub fn nodes(&self) -> Result<H3CellMap<NodeType>, Error>
cells which are valid targets to route to
This is a rather expensive operation as nodes are not stored anywhere and need to be extracted from the edges.
pub fn iter_edges(&self) -> impl Iterator<Item = (H3DirectedEdge, &W)>