Struct h3ron_graph::graph::h3edge::H3EdgeGraph [−][src]
pub struct H3EdgeGraph<W: Send + Sync> {
pub edges: ThreadPartitionedMap<H3Edge, W>,
pub h3_resolution: u8,
}Fields
edges: ThreadPartitionedMap<H3Edge, W>h3_resolution: u8Implementations
This has to generate the node list first, so its rather expensive to call.
get all edges in the graph leading from this edge to neighbors
get all edges in the graph leading to this cell from its neighbors
pub fn add_edge_using_cells(
&mut self,
cell_from: H3Cell,
cell_to: H3Cell,
weight: W
) -> Result<(), Error>
pub fn add_edge_using_cells_bidirectional(
&mut self,
cell_from: H3Cell,
cell_to: H3Cell,
weight: W
) -> Result<(), Error>
cells which are valid targets to route to
This is a rather expensive operation as nodes are not stored anywhere and need to be extracted from the edges.