pub struct LongEdge {
pub in_edge: H3DirectedEdge,
pub out_edge: H3DirectedEdge,
/* private fields */
}Expand description
A LongEdge is an artificial construct to combine a continuous path
of H3DirectedEdge values into a single edge.
This intended to be used to compress longer paths into a single edge to reduce the number of nodes to visit during routing.
Fields
in_edge: H3DirectedEdgeout_edge: H3DirectedEdgeImplementations
sourceimpl LongEdge
impl LongEdge
pub fn destination_cell(&self) -> Result<H3Cell, Error>
pub fn origin_cell(&self) -> Result<H3Cell, Error>
pub fn is_disjoint(&self, celltreemap: &H3Treemap<H3Cell>) -> bool
sourcepub const fn h3edges_len(&self) -> usize
pub const fn h3edges_len(&self) -> usize
length of self as the number of contained h3edges
sourcepub fn h3edge_path(
&self
) -> Result<OwningDecompressedIter<'_, H3DirectedEdge>, Error>
pub fn h3edge_path(
&self
) -> Result<OwningDecompressedIter<'_, H3DirectedEdge>, Error>
the path of the longedge described by multiple, successive H3DirectedEdge values