Struct h3ron_graph::graph::longedge::LongEdge[][src]

pub struct LongEdge {
    pub in_edge: H3Edge,
    pub out_edge: H3Edge,
    // some fields omitted
}
A LongEdge is an artificial construct to combine a continuous path of H3Edge values into a single edge.

This intended to be used to compress longer paths into a single edge to reduce the number of nodes to visit during routing.

Fields

in_edge: H3Edgeout_edge: H3Edge

Implementations

length of self as the number of contained h3edges

the path of the longedge described by multiple, successive H3Edge values