Enum h3ron_graph::graph::node::GapBridgedCellNode [−][src]
pub enum GapBridgedCellNode {
DirectConnection(H3Cell),
WithGap(H3Cell, H3Cell),
NoConnection(H3Cell),
}Expand description
the type of membershipt a cell has within a graph
Variants
DirectConnection(H3Cell)the cell is connected to the graph
Tuple Fields of DirectConnection
0: H3Cellcell self.0 is not connected to the graph, but the next best neighbor self.1 is
NoConnection(H3Cell)cell is outside of the graph
Tuple Fields of NoConnection
0: H3Cell