Struct h3ron_graph::graph::prepared::PreparedH3EdgeGraph
source · [−]pub struct PreparedH3EdgeGraph<W> { /* private fields */ }Expand description
A prepared graph which can be used with a few algorithms.
Consequent H3DirectedEdges without forks get extended by a LongEdge to allow
skipping the individual H3DirectedEdge values for a more efficient graph
traversal.
Implementations
sourceimpl<W> PreparedH3EdgeGraph<W>
impl<W> PreparedH3EdgeGraph<W>
sourcepub fn count_edges(&self) -> (usize, usize)
pub fn count_edges(&self) -> (usize, usize)
count the number of edges in the graph
The returned tuple is (num_edges, num_long_edges)
sourceimpl<W> PreparedH3EdgeGraph<W>where
W: Copy,
impl<W> PreparedH3EdgeGraph<W>where
W: Copy,
sourcepub fn iter_edges(
&self
) -> impl Iterator<Item = (H3DirectedEdge, EdgeWeight<'_, W>)>
pub fn iter_edges(
&self
) -> impl Iterator<Item = (H3DirectedEdge, EdgeWeight<'_, W>)>
iterate over all edges of the graph
sourcepub fn iter_edges_non_overlapping(
&self
) -> Result<impl Iterator<Item = (H3DirectedEdge, EdgeWeight<'_, W>)>, Error>
pub fn iter_edges_non_overlapping(
&self
) -> Result<impl Iterator<Item = (H3DirectedEdge, EdgeWeight<'_, W>)>, Error>
iterate over all edges of the graph, while skipping simple H3DirectedEdge
which are already covered in other LongEdge instances of the graph.
This function iterates the graph twice - the first time to collect all edges which are part of long-edges.
sourceimpl<W> PreparedH3EdgeGraph<W>where
W: PartialOrd + PartialEq + Add + Copy + Ord + Zero + Send + Sync,
impl<W> PreparedH3EdgeGraph<W>where
W: PartialOrd + PartialEq + Add + Copy + Ord + Zero + Send + Sync,
pub fn from_h3edge_graph(
graph: H3EdgeGraph<W>,
min_longedge_length: usize
) -> Result<Self, Error>