pub struct PreparedH3EdgeGraph<W: Send + Sync> { /* private fields */ }
a prepared graph which can be used for routing

Consequent H3Edges without

Implementations

iterate over all edges of the graph

iterate over all edges of the graph, while skipping simple H3Edge which are already covered in other LongEdge instances of the graph.

This function iterates the graph twice - the first time to collect all edges which are part of long-edges.