Struct h3ron_graph::graph::prepared::PreparedH3EdgeGraph
source · [−]Expand description
a prepared graph which can be used for routing
Consequent H3Edges without
Implementations
iterate over all edges of the graph
pub fn iter_edges_non_overlapping(
&self
) -> Result<impl Iterator<Item = (H3Edge, EdgeWeight<'_, W>)>, Error>
pub fn iter_edges_non_overlapping(
&self
) -> Result<impl Iterator<Item = (H3Edge, EdgeWeight<'_, W>)>, Error>
iterate over all edges of the graph, while skipping simple H3Edge
which are already covered in other LongEdge instances of the graph.
This function iterates the graph twice - the first time to collect all edges which are part of long-edges.